@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,10 +15,26 @@
  */
 package org.kuali.rice.kew.rule.service.impl;
 
+import java.io.InputStream;
+import java.sql.Timestamp;
+import java.text.ParseException;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Comparator;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.UUID;
+
 import org.apache.commons.beanutils.PropertyUtils;
 import org.apache.commons.lang.ObjectUtils;
 import org.apache.commons.lang.StringUtils;
 import org.jdom.Element;
+import org.kuali.rice.core.api.CoreApiServiceLocator;
 import org.kuali.rice.core.api.impex.ExportDataSet;
 import org.kuali.rice.core.api.impex.xml.XmlConstants;
 import org.kuali.rice.core.api.resourceloader.GlobalResourceLoader;
@@ -27,6 +43,7 @@ import org.kuali.rice.core.api.util.collect.CollectionUtils;
 import org.kuali.rice.core.impl.cache.DistributedCacheManagerDecorator;
 import org.kuali.rice.coreservice.framework.CoreFrameworkServiceLocator;
 import org.kuali.rice.kew.actionrequest.service.ActionRequestService;
+import org.kuali.rice.kew.api.KewApiConstants;
 import org.kuali.rice.kew.api.KewApiServiceLocator;
 import org.kuali.rice.kew.api.WorkflowDocument;
 import org.kuali.rice.kew.api.WorkflowDocumentFactory;
@@ -61,7 +78,6 @@ import org.kuali.rice.kew.rule.service.RuleDelegationService;
 import org.kuali.rice.kew.rule.service.RuleServiceInternal;
 import org.kuali.rice.kew.rule.service.RuleTemplateService;
 import org.kuali.rice.kew.service.KEWServiceLocator;
-import org.kuali.rice.kew.api.KewApiConstants;
 import org.kuali.rice.kew.util.PerformanceLogger;
 import org.kuali.rice.kew.xml.RuleXmlParser;
 import org.kuali.rice.kew.xml.export.RuleXmlExporter;
@@ -70,26 +86,14 @@ import org.kuali.rice.kim.api.group.GroupService;
 import org.kuali.rice.kim.api.identity.principal.PrincipalContract;
 import org.kuali.rice.kim.api.services.KimApiServiceLocator;
 import org.kuali.rice.krad.UserSession;
+import org.kuali.rice.krad.data.DataObjectService;
 import org.kuali.rice.krad.util.GlobalVariables;
 import org.kuali.rice.krad.util.KRADConstants;
+import org.springframework.beans.factory.annotation.Required;
 import org.springframework.cache.Cache;
 
-import java.io.InputStream;
-import java.sql.Timestamp;
-import java.text.ParseException;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.Comparator;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.UUID;
-
 
+@SuppressWarnings("deprecation")
 public class RuleServiceInternalImpl implements RuleServiceInternal {
 
     private static final String XML_PARSE_ERROR = "general.error.parsexml";
@@ -98,15 +102,18 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
 
     private RuleDAO ruleDAO;
     private RuleResponsibilityDAO ruleResponsibilityDAO;
+    private DataObjectService dataObjectService;
 
     public RuleResponsibilityDAO getRuleResponsibilityDAO() {
         return ruleResponsibilityDAO;
     }
 
+    @Override
     public RuleBaseValues getRuleByName(String name) {
         return ruleDAO.findRuleBaseValuesByName(name);
     }
 
+    @Override
     public RuleBaseValues findDefaultRuleByRuleTemplateId(String ruleTemplateId){
         return this.ruleDAO.findDefaultRuleByRuleTemplateId(ruleTemplateId);
     }
@@ -114,6 +121,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         this.ruleResponsibilityDAO = ruleResponsibilityDAO;
     }
 
+    @Override
     public void save2(RuleBaseValues ruleBaseValues) throws Exception {
         save2(ruleBaseValues, null, true);
     }
@@ -149,10 +157,12 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         getRuleDAO().save(ruleBaseValues);
     }
 
+    @Override
     public void makeCurrent(String documentId) {
         makeCurrent(findByDocumentId(documentId));
     }
 
+    @SuppressWarnings("unchecked")
     public void makeCurrent(List<RuleBaseValues> rules) {
         PerformanceLogger performanceLogger = new PerformanceLogger();
 
@@ -242,6 +252,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
      * aren't being added or removed.  This is why it doesn't perform some of the functions like checking
      * for delegation rules that were removed from a parent rule.
      */
+    @SuppressWarnings("unchecked")
     public void makeCurrent2(List<RuleBaseValues> rules) {
         PerformanceLogger performanceLogger = new PerformanceLogger();
 
@@ -310,10 +321,12 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
      * Maintenance document.  Because of the changes in the data model and the front end here,
      * this method can be much less complicated than the previous 2!
      */
+    @Override
     public void makeCurrent(RuleBaseValues rule, boolean isRetroactiveUpdatePermitted) {
     	makeCurrent(null, rule, isRetroactiveUpdatePermitted);
     }
 
+    @Override
     public void makeCurrent(RuleDelegationBo ruleDelegation, boolean isRetroactiveUpdatePermitted) {
         clearCache(RuleDelegation.Cache.NAME);
     	makeCurrent(ruleDelegation, ruleDelegation.getDelegationRule(), isRetroactiveUpdatePermitted);
@@ -335,51 +348,61 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
 
         performanceLogger.log("Preparing rule: " + rule.getDescription());
 
-        Map<String, RuleBaseValues> rulesToSave = new HashMap<String, RuleBaseValues>();
         generateRuleNameIfNeeded(rule);
         assignResponsibilityIds(rule);
         rule.setCurrentInd(Boolean.TRUE);
-        Timestamp date = new Timestamp(System.currentTimeMillis());
+        Timestamp date = CoreApiServiceLocator.getDateTimeService().getCurrentTimestamp();
         rule.setActivationDate(date);
         rule.setDeactivationDate(null);
-
-        rulesToSave.put(rule.getId(), rule);
-        if (rule.getPreviousRuleId() != null) {
-        	RuleBaseValues oldRule = findRuleBaseValuesById(rule.getPreviousRuleId());
-        	rule.setPreviousVersion(oldRule);
-        }
-        rule.setVersionNbr(0);
+        rule.setVersionNumber(null);
         rule.setObjectId(null);
-        RuleBaseValues oldRule = rule.getPreviousVersion();
+
+        RuleBaseValues oldRule = null;
+        if (rule.getPreviousRuleId() != null) {
+        	oldRule = findRuleBaseValuesById(rule.getPreviousRuleId());
+        }
         if (oldRule != null) {
         	performanceLogger.log("Setting previous rule: " + oldRule.getId() + " to non current.");
         	oldRule.setCurrentInd(Boolean.FALSE);
         	oldRule.setDeactivationDate(date);
-        	rulesToSave.put(oldRule.getId(), oldRule);
         	responsibilityIds.addAll(getModifiedResponsibilityIds(oldRule, rule));
         	rule.setVersionNbr(getNextVersionNumber(oldRule));
+            oldRule = getRuleDAO().save(oldRule);
+            rule.setPreviousVersion(oldRule);
+            performanceLogger.log("Saved old rule: " + oldRule.getId());
         }
-               
+
+//        }
+
+        for(RuleResponsibilityBo ruleResponsibilityBo : rule.getRuleResponsibilities()){
+            if(StringUtils.isBlank(ruleResponsibilityBo.getId())){
+                ruleResponsibilityBo.setVersionNumber(null);
+            }
+            ruleResponsibilityBo.setRuleBaseValues(rule);
+        }
+
+
+
+        // now save the new rule
+        rule = getRuleDAO().save(rule);
+      	performanceLogger.log("Saved rule: " + rule.getId());
 
         boolean isRuleDelegation = ruleDelegation != null;
-        
-        for (RuleBaseValues ruleToSave : rulesToSave.values()) {
-        	getRuleDAO().save(ruleToSave);
-        	performanceLogger.log("Saved rule: " + ruleToSave.getId());
-        }
         if (isRuleDelegation) {
+            // update our reference to the delegation rule, because it could have changed
+            ruleDelegation.setDelegationRule(rule);
         	responsibilityIds.add(ruleDelegation.getResponsibilityId());
         	ruleDelegation.setDelegateRuleId(rule.getId());
         	getRuleDelegationService().save(ruleDelegation);
         }
-        
+
         if (isGenerateRuleArs
                 && org.apache.commons.collections.CollectionUtils.isNotEmpty(responsibilityIds)) {
             getActionRequestService().updateActionRequestsForResponsibilityChange(responsibilityIds);
         }
         performanceLogger.log("Time to make current");
     }
-    
+
     private void clearCache(String cacheName) {
         DistributedCacheManagerDecorator distributedCacheManagerDecorator =
                 GlobalResourceLoader.getService(KewImplConstants.KEW_DISTRIBUTED_CACHE_MANAGER);
@@ -390,10 +413,12 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         }
     }
 
+    @Override
     public RuleBaseValues getParentRule(String ruleBaseValuesId) {
         return getRuleDAO().getParentRule(ruleBaseValuesId);
     }
 
+    @SuppressWarnings({"rawtypes", "unchecked"})
     private Set getResponsibilityIdsFromGraph(RuleBaseValues rule, boolean isRuleCollecting) {
         Set responsibilityIds = new HashSet();
         for (Object element : rule.getRuleResponsibilities()) {
@@ -445,6 +470,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
      * This method will find any old delegation rules on the previous version of the parent rule which are not on the
      * new version of the rule so that they can be marked non-current.
      */
+    @SuppressWarnings("unchecked")
     private List<RuleBaseValues> findOldDelegationRules(RuleBaseValues oldRule, RuleBaseValues newRule, PerformanceLogger performanceLogger) {
         performanceLogger.log("Begin to get delegation rules.");
         List<RuleBaseValues> oldDelegations = getRuleDAO().findOldDelegations(oldRule, newRule);
@@ -452,6 +478,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         return oldDelegations;
     }
 
+    @Override
     public String routeRuleWithDelegate(String documentId, RuleBaseValues parentRule, RuleBaseValues delegateRule, PrincipalContract principal, String annotation, boolean blanketApprove) throws Exception {
         if (parentRule == null) {
             throw new IllegalArgumentException("Cannot route a delegate without a parent rule.");
@@ -495,7 +522,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         if (documentId != null) {
             workflowDocument = WorkflowDocumentFactory.loadDocument(principal.getPrincipalId(), documentId);
         } else {
-            List rules = new ArrayList();
+            List<RuleBaseValues> rules = new ArrayList<RuleBaseValues>();
             rules.add(delegateRule);
             rules.add(parentRule);
             workflowDocument = WorkflowDocumentFactory.createDocument(principal.getPrincipalId(), getRuleDocumentTypeName(
@@ -545,6 +572,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         return title.toString();
     }
 
+    @SuppressWarnings({"unchecked", "rawtypes"})
     public void validate(RuleBaseValues ruleBaseValues, List errors) {
         if (errors == null) {
             errors = new ArrayList();
@@ -577,6 +605,8 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         }
     }
 
+    @SuppressWarnings("unchecked")
+    @Override
     public void validate2(RuleBaseValues ruleBaseValues, RuleDelegationBo ruleDelegation, List errors) {
         if (errors == null) {
             errors = new ArrayList();
@@ -657,16 +687,21 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         }
     }
 
+    @Override
     public List<RuleBaseValues> findByDocumentId(String documentId) {
         return getRuleDAO().findByDocumentId(documentId);
     }
 
+    @SuppressWarnings("rawtypes")
+    @Override
     public List<RuleBaseValues> search(String docTypeName, String ruleId, String ruleTemplateId, String ruleDescription, String groupId, String principalId,
             Boolean delegateRule, Boolean activeInd, Map extensionValues, String workflowIdDirective) {
         return getRuleDAO().search(docTypeName, ruleId, ruleTemplateId, ruleDescription, groupId, principalId, delegateRule,
                 activeInd, extensionValues, workflowIdDirective);
     }
 
+    @SuppressWarnings("rawtypes")
+    @Override
     public List<RuleBaseValues> searchByTemplate(String docTypeName, String ruleTemplateName, String ruleDescription, String groupId, String principalId,
             Boolean workgroupMember, Boolean delegateRule, Boolean activeInd, Map extensionValues, Collection<String> actionRequestCodes) {
 
@@ -714,35 +749,43 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
                 delegateRule,activeInd, extensionValues, actionRequestCodes);
     }
 
+    @Override
     public void delete(String ruleBaseValuesId) {
         getRuleDAO().delete(ruleBaseValuesId);
     }
 
+    @Override
     public RuleBaseValues findRuleBaseValuesById(String ruleBaseValuesId) {
         return getRuleDAO().findRuleBaseValuesById(ruleBaseValuesId);
     }
 
+    @Override
     public RuleResponsibilityBo findRuleResponsibility(String responsibilityId) {
         return getRuleDAO().findRuleResponsibility(responsibilityId);
     }
 
+    @Override
     public List fetchAllCurrentRulesForTemplateDocCombination(String ruleTemplateName, String documentType) {
         	String ruleTemplateId = getRuleTemplateService().findByRuleTemplateName(ruleTemplateName).getId();
             return getRuleDAO().fetchAllCurrentRulesForTemplateDocCombination(ruleTemplateId, getDocGroupAndTypeList(documentType));
     }
 
+    @Override
     public List fetchAllCurrentRulesForTemplateDocCombination(String ruleTemplateName, String documentType, Timestamp effectiveDate){
         String ruleTemplateId = getRuleTemplateService().findByRuleTemplateName(ruleTemplateName).getId();
         PerformanceLogger performanceLogger = new PerformanceLogger();
         performanceLogger.log("Time to fetchRules by template " + ruleTemplateName + " not caching.");
         return getRuleDAO().fetchAllCurrentRulesForTemplateDocCombination(ruleTemplateId, getDocGroupAndTypeList(documentType), effectiveDate);
     }
+    @SuppressWarnings("unchecked")
+    @Override
     public List fetchAllRules(boolean currentRules) {
         return getRuleDAO().fetchAllRules(currentRules);
     }
 
+    @SuppressWarnings("rawtypes")
     private List getDocGroupAndTypeList(String documentType) {
-        List docTypeList = new ArrayList();
+        List<String> docTypeList = new ArrayList<String>();
         DocumentTypeService docTypeService = (DocumentTypeService) KEWServiceLocator.getService(KEWServiceLocator.DOCUMENT_TYPE_SERVICE);
         DocumentType docType = docTypeService.findByName(documentType);
         while (docType != null) {
@@ -752,8 +795,9 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         return docTypeList;
     }
 
+    @SuppressWarnings("rawtypes")
     private Integer getNextVersionNumber(RuleBaseValues currentRule) {
-        List candidates = new ArrayList();
+        List<Integer> candidates = new ArrayList<Integer>();
         candidates.add(currentRule.getVersionNbr());
         List pendingRules = ruleDAO.findByPreviousRuleId(currentRule.getId());
         for (Iterator iterator = pendingRules.iterator(); iterator.hasNext();) {
@@ -775,6 +819,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
      *
      * In the case of a new delegate rule or a delegate rule edit, this method will take the id of it's parent.
      */
+    @Override
     public String isLockedForRouting(String currentRuleBaseValuesId) {
         // checks for any other versions of the given rule, essentially, if this is a rule edit we want to see how many other
         // pending edits are out there
@@ -845,6 +890,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
      *
      * TODO this method ended up being a mess, we should get rid of this as soon as we can
      */
+    @Override
     public String getRuleDocumentTypeName(List rules) {
         if (rules.size() == 0) {
             throw new IllegalArgumentException("Cannot determine rule DocumentType for an empty list of rules.");
@@ -892,18 +938,22 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         return ruleDAO;
     }
 
+    @Override
     public void deleteRuleResponsibilityById(String ruleResponsibilityId) {
-        getRuleResponsibilityDAO().delete(ruleResponsibilityId);
+        getDataObjectService().delete(ruleResponsibilityId);
     }
 
+    @Override
     public RuleResponsibilityBo findByRuleResponsibilityId(String ruleResponsibilityId) {
-        return getRuleResponsibilityDAO().findByRuleResponsibilityId(ruleResponsibilityId);
+        return getDataObjectService().find(RuleResponsibilityBo.class,ruleResponsibilityId);
     }
 
+    @Override
     public List findRuleBaseValuesByResponsibilityReviewer(String reviewerName, String type) {
         return getRuleDAO().findRuleBaseValuesByResponsibilityReviewer(reviewerName, type);
     }
 
+    @Override
     public List findRuleBaseValuesByResponsibilityReviewerTemplateDoc(String ruleTemplateName, String documentType, String reviewerName, String type) {
         return getRuleDAO().findRuleBaseValuesByResponsibilityReviewerTemplateDoc(ruleTemplateName, documentType, reviewerName, type);
     }
@@ -940,6 +990,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
      * A comparator implementation which compares RuleBaseValues and puts all delegate rules first.
      */
     public class RuleDelegationSorter implements Comparator {
+        @Override
         public int compare(Object arg0, Object arg1) {
             RuleBaseValues rule1 = (RuleBaseValues) arg0;
             RuleBaseValues rule2 = (RuleBaseValues) arg1;
@@ -952,6 +1003,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
     }
 
 
+    @Override
     public void loadXml(InputStream inputStream, String principalId) {
         RuleXmlParser parser = new RuleXmlParser();
         try {
@@ -964,11 +1016,12 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         }
     }
 
+    @Override
     public Element export(ExportDataSet dataSet) {
         RuleXmlExporter exporter = new RuleXmlExporter(XmlConstants.RULE_NAMESPACE);
         return exporter.export(dataSet);
     }
-    
+
     @Override
 	public boolean supportPrettyPrint() {
 		return true;
@@ -1018,8 +1071,8 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
     protected void hookUpDelegateRuleToParentRule(RuleBaseValues newParentRule, RuleBaseValues newDelegationRule, RuleDelegationBo existingRuleDelegation) {
         // hook up parent rule to new rule delegation
         boolean foundDelegation = false;
-        outer:for (RuleResponsibilityBo responsibility : (List<RuleResponsibilityBo>)newParentRule.getRuleResponsibilities()) {
-            for (RuleDelegationBo ruleDelegation : (List<RuleDelegationBo>)responsibility.getDelegationRules()) {
+        outer:for (RuleResponsibilityBo responsibility : newParentRule.getRuleResponsibilities()) {
+            for (RuleDelegationBo ruleDelegation : responsibility.getDelegationRules()) {
                 if (ruleDelegation.getDelegationRule().getId().equals(existingRuleDelegation.getDelegationRule().getId())) {
                     ruleDelegation.setDelegationRule(newDelegationRule);
                     foundDelegation = true;
@@ -1041,19 +1094,19 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         rule.setId(null);
         rule.setActivationDate(null);
         rule.setDeactivationDate(null);
-        rule.setVersionNumber(0L);
+        rule.setVersionNumber(null);
         rule.setDocumentId(documentId);
 
         // TODO: FIXME: need to copy the rule expression here too?
 
-        rule.setRuleResponsibilities(new ArrayList());
-        for (RuleResponsibilityBo existingResponsibility : (List<RuleResponsibilityBo>)existingRule.getRuleResponsibilities()) {
+        rule.setRuleResponsibilities(new ArrayList<RuleResponsibilityBo>());
+        for (RuleResponsibilityBo existingResponsibility : existingRule.getRuleResponsibilities()) {
             RuleResponsibilityBo responsibility = new RuleResponsibilityBo();
             PropertyUtils.copyProperties(responsibility, existingResponsibility);
             responsibility.setRuleBaseValues(rule);
             responsibility.setRuleBaseValuesId(null);
             responsibility.setId(null);
-            responsibility.setVersionNumber(0L);
+            responsibility.setVersionNumber(null);
             rule.getRuleResponsibilities().add(responsibility);
 //            responsibility.setDelegationRules(new ArrayList());
 //            for (RuleDelegation existingDelegation : (List<RuleDelegation>)existingResponsibility.getDelegationRules()) {
@@ -1069,7 +1122,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
 //            }
         }
         rule.setRuleExtensions(new ArrayList());
-        for (RuleExtensionBo existingExtension : (List<RuleExtensionBo>)existingRule.getRuleExtensions()) {
+        for (RuleExtensionBo existingExtension : existingRule.getRuleExtensions()) {
             RuleExtensionBo extension = new RuleExtensionBo();
             PropertyUtils.copyProperties(extension, existingExtension);
             extension.setVersionNumber(new Long(0));
@@ -1082,7 +1135,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
                 RuleExtensionValue extensionValue = new RuleExtensionValue();
                 PropertyUtils.copyProperties(extensionValue, existingExtensionValue);
                 extensionValue.setExtension(extension);
-                extensionValue.setRuleExtensionId(null);
+                extensionValue.getExtension().setRuleExtensionId(null);
                 extensionValue.setLockVerNbr(0);
                 extensionValue.setRuleExtensionValueId(null);
                 extension.getExtensionValues().add(extensionValue);
@@ -1139,6 +1192,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         }
     }
 
+    @Override
     public String getDuplicateRuleId(RuleBaseValues rule) {
 
     	// TODO: this method is extremely slow, if we could implement a more optimized query here, that would help tremendously
@@ -1183,14 +1237,16 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
     	}
     }
 
+    @Override
     public RuleBaseValues saveRule(RuleBaseValues rule, boolean isRetroactiveUpdatePermitted) {
     	rule.setPreviousRuleId(rule.getId());
 		rule.setPreviousVersion(null);
 		rule.setId(null);
 		makeCurrent(rule, isRetroactiveUpdatePermitted);
-		return rule;
+		return getRuleDAO().findRuleBaseValuesByName(rule.getName());
     }
 
+    @Override
     public List<RuleBaseValues> saveRules(List<RuleBaseValues> rulesToSave, boolean isRetroactiveUpdatePermitted) {
     	List<RuleBaseValues> savedRules = new ArrayList<RuleBaseValues>();
     	for (RuleBaseValues rule : rulesToSave) {
@@ -1200,16 +1256,21 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
     	return savedRules;
     }
 
+    @Override
     public RuleDelegationBo saveRuleDelegation(RuleDelegationBo ruleDelegation, boolean isRetroactiveUpdatePermitted) {
     	RuleBaseValues rule = ruleDelegation.getDelegationRule();
+        //rule = (RuleBaseValues)SerializationUtils.deepCopy(rule);
 		rule.setPreviousRuleId(rule.getId());
 		rule.setPreviousVersion(null);
 		rule.setId(null);
 		ruleDelegation.setRuleDelegationId(null);
+
+        ruleDelegation.setDelegationRule(rule);
 		makeCurrent(ruleDelegation, isRetroactiveUpdatePermitted);
 		return ruleDelegation;
     }
 
+    @Override
     public List<RuleDelegationBo> saveRuleDelegations(List<RuleDelegationBo> ruleDelegationsToSave, boolean isRetroactiveUpdatePermitted) {
     	List<RuleDelegationBo> savedRuleDelegations = new ArrayList<RuleDelegationBo>();
     	for (RuleDelegationBo ruleDelegation : ruleDelegationsToSave) {
@@ -1219,6 +1280,7 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
     	return savedRuleDelegations;
     }
 
+    @Override
     public String findResponsibilityIdForRule(String ruleName, String ruleResponsibilityName, String ruleResponsibilityType) {
     	return getRuleDAO().findResponsibilityIdForRule(ruleName, ruleResponsibilityName, ruleResponsibilityType);
     }
@@ -1227,4 +1289,14 @@ public class RuleServiceInternalImpl implements RuleServiceInternal {
         return "'templateName=' + " + ruleTemplateName +" '|' + 'documentTypeName=' + " + docTypeName;
     }
 
+    public DataObjectService getDataObjectService() {
+        return dataObjectService;
+    }
+
+    @Required
+    public void setDataObjectService(DataObjectService dataObjectService) {
+        this.dataObjectService = dataObjectService;
+    }
+
+
 }
