@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -738,7 +738,7 @@ public abstract class AbstractLookupableHelperServiceImpl implements LookupableH
      * @return Returns the backLocation.
      */
     public String getBackLocation() {
-    	return WebUtils.sanitizeBackLocation(this.backLocation);
+        return WebUtils.sanitizeBackLocation(backLocation);
     }
 
     /**
