@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -65,6 +65,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 import javax.servlet.jsp.PageContext;
+import java.io.BufferedInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -369,9 +370,12 @@ public class WebUtils {
 
 		// write to output
 		OutputStream out = response.getOutputStream();
-		while (inStream.available() > 0) {
-			out.write(inStream.read());
+		BufferedInputStream is = new BufferedInputStream(inStream);
+		int data;
+		while ((data = is.read()) != -1) {
+			out.write(data);
 		}
+		is.close();
 		out.flush();
 	}
 
@@ -955,11 +959,11 @@ public class WebUtils {
         }
         return base + path;
     }
-    
-    public static String sanitizeBackLocation(String backLocation) {
-        if(StringUtils.isBlank(backLocation)) {
-            return backLocation;
-        }
+
+	public static String sanitizeBackLocation(String backLocation) {
+		if(StringUtils.isBlank(backLocation)) {
+			return backLocation;
+		}
 		// if it's a relative URL then we should be good regardless
 		try {
 			URI uri = new URI(backLocation);
@@ -969,12 +973,12 @@ public class WebUtils {
 		} catch (URISyntaxException e) {
 			// move on to the other checks if it doesn't parse up as a URI for some reason
 		}
-        Pattern pattern = Pattern.compile(ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.BACK_LOCATION_ALLOWED_REGEX));
-        if(pattern.matcher(backLocation).matches()) {
-            return backLocation;
-        } else {
-            return ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.BACK_LOCATION_DEFAULT_URL);
-        }
-    }
+		Pattern pattern = Pattern.compile(ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.BACK_LOCATION_ALLOWED_REGEX));
+		if(pattern.matcher(backLocation).matches()) {
+			return backLocation;
+		} else {
+			return ConfigContext.getCurrentContextConfig().getProperty(KRADConstants.BACK_LOCATION_DEFAULT_URL);
+		}
+	}
 
 }
