@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,28 +15,42 @@
  */
 package org.kuali.rice.krad.datadictionary;
 
+import java.io.Serializable;
+import java.util.ArrayList;
+import java.util.HashSet;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+
 import org.apache.commons.lang.StringUtils;
+import org.kuali.rice.krad.data.KradDataServiceLocator;
+import org.kuali.rice.krad.data.metadata.DataObjectAttribute;
+import org.kuali.rice.krad.data.metadata.DataObjectAttributeRelationship;
+import org.kuali.rice.krad.data.metadata.DataObjectCollection;
+import org.kuali.rice.krad.data.metadata.DataObjectMetadata;
+import org.kuali.rice.krad.data.metadata.DataObjectRelationship;
+import org.kuali.rice.krad.data.provider.MetadataProvider;
+import org.kuali.rice.krad.data.provider.annotation.UifDisplayHint;
+import org.kuali.rice.krad.data.provider.annotation.UifDisplayHintType;
 import org.kuali.rice.krad.datadictionary.exception.DuplicateEntryException;
 import org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute;
 import org.kuali.rice.krad.datadictionary.state.StateMapping;
 import org.kuali.rice.krad.datadictionary.validator.ValidationTrace;
 import org.kuali.rice.krad.exception.ValidationException;
 import org.springframework.beans.BeanUtils;
-import org.springframework.beans.factory.InitializingBean;
-
-import java.io.Serializable;
-import java.util.ArrayList;
-import java.util.LinkedHashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
 
 /**
  * Contains common properties and methods for data dictionary entries
  *
  * @author Kuali Rice Team (rice.collab@kuali.org)
  */
-abstract public class DataDictionaryEntryBase extends DictionaryBeanBase implements DataDictionaryEntry, Serializable, InitializingBean {
+abstract public class DataDictionaryEntryBase extends DictionaryBeanBase implements DataDictionaryEntry, Serializable {
+    private static final org.apache.log4j.Logger LOG = org.apache.log4j.Logger.getLogger(DataDictionaryEntryBase.class);
+    private static final long serialVersionUID = 5133059101016080533L;
+
+    protected DataObjectMetadata dataObjectMetadata;
+
     protected List<AttributeDefinition> attributes;
     protected List<ComplexAttributeDefinition> complexAttributes;
     protected List<CollectionDefinition> collections;
@@ -44,6 +58,7 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
     protected Map<String, AttributeDefinition> attributeMap;
     protected Map<String, ComplexAttributeDefinition> complexAttributeMap;
     protected Map<String, CollectionDefinition> collectionMap;
+
     protected Map<String, RelationshipDefinition> relationshipMap;
 
     protected StateMapping stateMapping;
@@ -66,6 +81,7 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
      * @param attributeName
      * @return AttributeDefinition with the given name, or null if none with that name exists
      */
+    @Override
     public AttributeDefinition getAttributeDefinition(String attributeName) {
         if (StringUtils.isBlank(attributeName)) {
             throw new IllegalArgumentException("invalid (blank) attributeName");
@@ -96,11 +112,11 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
         complexAttributeMap.clear();
         for (ComplexAttributeDefinition complexAttribute : complexAttributes) {
             if (complexAttribute == null) {
-                throw new IllegalArgumentException("invalid (null) complexAttributeDefinition");
+                throw new DataDictionaryException("invalid (null) complexAttributeDefinition on " + this);
             }
             String complexAttributeName = complexAttribute.getName();
             if (StringUtils.isBlank(complexAttributeName)) {
-                throw new ValidationException("invalid (blank) collectionName");
+                throw new DataDictionaryException("invalid (blank) complexAttributeName on " + this);
             }
 
             if (complexAttributeMap.containsKey(complexAttribute)) {
@@ -158,13 +174,14 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
         if (StringUtils.isBlank(relationshipName)) {
             throw new IllegalArgumentException("invalid (blank) relationshipName");
         }
-        return relationshipMap.get(relationshipName);
+        return getRelationshipMap().get(relationshipName);
     }
 
     /**
      * @return a Map containing all RelationshipDefinitions associated with this BusinessObjectEntry, indexed by
      *         relationshipName
      */
+    @Override
     @BeanTagAttribute(name = "relationships", type = BeanTagAttribute.AttributeType.LISTBEAN)
     public List<RelationshipDefinition> getRelationships() {
         return this.relationships;
@@ -173,18 +190,224 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
     /**
      * Directly validate simple fields, call completeValidation on Definition fields.
      */
+    @Override
     public void completeValidation() {
+        completeValidation( new ValidationTrace() );
+    }
 
-        for (AttributeDefinition attributeDefinition : attributes) {
-            attributeDefinition.completeValidation(getEntryClass(), null);
+    protected void embedMetadata() {
+        // Once we get to this point, the providers must also be loaded
+        // See if this DataObjectEntry's class has associated metadata
+        MetadataProvider metadataProvider = KradDataServiceLocator.getProviderRegistry().getMetadataProvider(getEntryClass());
+        if ( metadataProvider != null ) {
+            dataObjectMetadata = metadataProvider.getMetadataForType(getEntryClass());
+            if ( dataObjectMetadata == null ) {
+                LOG.warn( "No metadata defined for " + getEntryClass() + " even though provider returned." );
+            } else {
+                // Since we have metadata, attempt to match it up on property name with the attributes defined
+                // We want to do this before calling the super.completeValidation() as it will validate that the
+                // AttributeDefinition objects have certain values and we want to take advantage of defaulting from
+                // the metadata model
+                injectMetadataIntoAttributes(dataObjectMetadata);
+                injectMetadataIntoCollections(dataObjectMetadata);
+                injectMetadataIntoRelationships(dataObjectMetadata);
+            }
+        } else {
+            LOG.info( "No metadata provider exists which handles: " + getEntryClass());
+        }
+    }
+
+    /**
+     * Inject the metadata into the relationship definitions.  Unlike attributes, in this case
+     * we only add missing relationships.  If a relationship was defined for a given attribute
+     * we leave it alone.
+     *
+     * @param dataObjectMetadata
+     */
+    protected void injectMetadataIntoRelationships(DataObjectMetadata dataObjectMetadata) {
+        List<RelationshipDefinition> relationships = getRelationships();
+        boolean relationshipsChanged = false;
+        if ( relationships == null ) {
+            relationships = new ArrayList<RelationshipDefinition>();
+        }
+        for ( DataObjectRelationship rel : dataObjectMetadata.getRelationships() ) {
+            if ( rel.getAttributeRelationships().isEmpty() ) {
+                // If we have no attributes to link with, we don't have anything to contribute
+                continue;
+            }
+            if ( StringUtils.isNotBlank(rel.getName()) ) {
+                RelationshipDefinition relationshipDefinition = getRelationshipDefinition(rel.getName());
+                // no relationship defined for attribute - proceed and the given relationship parent is not
+                //included in a previous relationship so as not to add duplicates
+                if ( relationshipDefinition == null ){//&& !relationshipParentExists(rel.getName())) {
+                    relationshipDefinition = new RelationshipDefinition();
+                    relationshipDefinition.setObjectAttributeName(rel.getName());
+                    relationshipDefinition.setSourceClass(getEntryClass());
+                    relationshipDefinition.setTargetClass(rel.getRelatedType());
+                    for ( DataObjectAttributeRelationship attrRel : rel.getAttributeRelationships() ) {
+                        PrimitiveAttributeDefinition attrDef = new PrimitiveAttributeDefinition();
+                        attrDef.setSourceName(attrRel.getParentAttributeName());
+                        attrDef.setTargetName(attrRel.getChildAttributeName());
+                        relationshipDefinition.getPrimitiveAttributes().add(attrDef);
+                    }
+                    relationshipDefinition.setGeneratedFromMetadata(true);
+                    relationshipDefinition.setEmbeddedDataObjectMetadata(true);
+                    relationships.add(relationshipDefinition);
+                    relationshipsChanged = true;
+                }
+            } else {
+                LOG.warn( "Relationship in metadata model contained blank name attribute: " + rel );
+            }
+        }
+    }
+
+    protected void injectMetadataIntoCollections(DataObjectMetadata dataObjectMetadata) {
+        List<CollectionDefinition> collections = getCollections();
+        boolean collectionsChanged = false;
+        if ( collections == null ) {
+            collections = new ArrayList<CollectionDefinition>();
+        }
+        for ( DataObjectCollection coll : dataObjectMetadata.getCollections() ) {
+            if ( StringUtils.isNotBlank(coll.getName()) ) {
+                // Odd special case where a list attribute has been mapped as a singular attribute in the DD.
+                // Due to validation logic, a given name can not be both a collection and an attribute.
+                if ( getAttributeDefinition(coll.getName()) != null ) {
+                    continue;
+                }
+                CollectionDefinition collectionDefinition = getCollectionDefinition(coll.getName());
+                // no relationship defined for attribute - proceed
+                if ( collectionDefinition == null ) {
+                    collectionDefinition = new CollectionDefinition();
+                    collectionDefinition.setName(coll.getName());
+                    collectionDefinition.setDataObjectClass(coll.getRelatedType().getName());
+                    collectionDefinition.setGeneratedFromMetadata(true);
+                    collections.add(collectionDefinition);
+                    // only need to trigger re-indexing if we add a new collection
+                    collectionsChanged = true;
+                }
+                collectionDefinition.setDataObjectCollection(coll);
+                collectionDefinition.setEmbeddedDataObjectMetadata(true);
+            } else {
+                LOG.warn( "Relationship in metadata model contained blank name attribute: " + coll );
+            }
+        }
+        // now that we are done, we need to set the resulting list back to the entry
+        // This triggers the needed indexing
+        if ( collectionsChanged ) {
+            setCollections(collections);
+        }
+    }
+
+    protected static final Set<String> EXCLUDED_PROPERTY_NAMES = new HashSet<String>();
+    static {
+        EXCLUDED_PROPERTY_NAMES.add("objectId");
+        EXCLUDED_PROPERTY_NAMES.add("versionNumber");
+    }
+
+    protected void injectMetadataIntoAttributes( DataObjectMetadata dataObjectMetadata ) {
+        List<AttributeDefinition> originalDataObjectEntryAttributes = getAttributes();
+        // this should never happen, but just in case someone was pathological enough to set it to null manually, let's be prepared
+        // We will use this to restore any UIF-Only attributes.
+        if ( originalDataObjectEntryAttributes == null ) {
+            originalDataObjectEntryAttributes = new ArrayList<AttributeDefinition>();
+        }
+        // This is the list we will set
+        List<AttributeDefinition> dataObjectEntryAttributes = new ArrayList<AttributeDefinition>();
+        // We are going to loop over the data in the metadata instead of the DD
+        // because we want to add attribute definitions if they do not exist
+        // and we don't care about attributes which only exist in the DD
+        for ( DataObjectAttribute attr : dataObjectMetadata.getAttributes() ) {
+            if ( StringUtils.isBlank(attr.getName())) {
+                LOG.warn( "Attribute in metadata model contained blank name attribute: " + attr );
+                continue;
+            }
+            // certain old properties we never want to see
+            if ( EXCLUDED_PROPERTY_NAMES.contains( attr.getName() ) ) {
+                continue;
+            }
+            // if we've been told to exclude it, just ignore
+            if ( hasExcludedHint(attr) ) {
+                continue;
+            }
+
+            AttributeDefinition attributeDefinition = getAttributeDefinition(attr.getName());
+            originalDataObjectEntryAttributes.remove(attributeDefinition);
+
+            if ( attributeDefinition == null ) {
+                attributeDefinition = new AttributeDefinition();
+                attributeDefinition.setName(attr.getName());
+                attributeDefinition.setGeneratedFromMetadata(true);
+            }
+
+            attributeDefinition.setDataObjectAttribute(attr);
+            attributeDefinition.setEmbeddedDataObjectMetadata(true);
+            dataObjectEntryAttributes.add(attributeDefinition);
+        }
+        // Add any which remain in this list to the end
+        dataObjectEntryAttributes.addAll(originalDataObjectEntryAttributes);
+        // now that we are done, we need to set the resulting list back to the entry
+        // This triggers the needed indexing
+        setAttributes(dataObjectEntryAttributes);
+    }
+
+    /**
+     * Check the {@link UifDisplayHint}s on an attribute, return true if any of them have the
+     * EXCLUDE type.
+     */
+    protected boolean hasExcludedHint( DataObjectAttribute attr ) {
+        if ( attr.getDisplayHints() != null ) {
+            for ( UifDisplayHint hint : attr.getDisplayHints() ) {
+                if ( hint.value().equals(UifDisplayHintType.EXCLUDE) ) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
+    @Override
+    public void dataDictionaryPostProcessing() {
+        super.dataDictionaryPostProcessing();
+        embedMetadata();
+        if (relationships != null) {
+            relationshipMap.clear();
+            
+            for (RelationshipDefinition relationship : relationships) {
+                if (relationship == null) {
+                    LOG.warn("Skipping invalid (null) relationshipDefinition on " + this);
+                    continue;
+                }
+                
+                String relationshipName = relationship.getObjectAttributeName();
+                if (StringUtils.isBlank(relationshipName)) {
+                    LOG.warn("Skipping invalid relationshipDefinition with blank relationshipName on " + this);
+                    continue;
+                }
+                
+                relationship.setSourceClass(getEntryClass());
+                relationshipMap.put(relationshipName, relationship);
+            }
         }
 
-        for (CollectionDefinition collectionDefinition : collections) {
-            collectionDefinition.completeValidation(getEntryClass(), null);
+        //Populate attributes with nested attribute definitions
+        if (complexAttributes != null) {            
+            for (ComplexAttributeDefinition complexAttribute : complexAttributes) {
+                if ( complexAttribute != null ) {
+                    addNestedAttributes(complexAttribute, complexAttribute.getName());
+                }
+            }
         }
-
-        for (RelationshipDefinition relationshipDefinition : relationships) {
-            relationshipDefinition.completeValidation(getEntryClass(), null);
+        
+        for (AttributeDefinition definition : getAttributes()) {
+            definition.dataDictionaryPostProcessing();
+        }
+        
+        for (CollectionDefinition definition : getCollections()) {
+            definition.dataDictionaryPostProcessing();
+        }
+        
+        for (RelationshipDefinition definition : getRelationships()) {
+            definition.dataDictionaryPostProcessing();
         }
     }
 
@@ -194,15 +417,25 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
      *
      * @see org.kuali.rice.krad.datadictionary.DataDictionaryEntry#completeValidation(org.kuali.rice.krad.datadictionary.validator.ValidationTrace)
      */
+    @Override
     public void completeValidation(ValidationTrace tracer) {
-        for (AttributeDefinition definition : getAttributes()) {
-            definition.completeValidation(getEntryClass(), null, tracer.getCopy());
-        }
-        for (CollectionDefinition definition : getCollections()) {
-            definition.completeValidation(getEntryClass(), null, tracer.getCopy());
-        }
-        for (RelationshipDefinition definition : getRelationships()) {
-            definition.completeValidation(getEntryClass(), null, tracer.getCopy());
+        if ( getEntryClass() != null ) {
+            if ( LOG.isDebugEnabled() ) {
+                LOG.debug( "Processing Validation for " + this.getClass().getSimpleName() + " for class: " + getEntryClass().getName() );
+            }
+            tracer.addBean(this.getClass().getSimpleName(), getEntryClass().getSimpleName());
+            for (AttributeDefinition definition : getAttributes()) {
+                definition.completeValidation(getEntryClass(), null, tracer.getCopy());
+            }
+            for (CollectionDefinition definition : getCollections()) {
+                definition.completeValidation(getEntryClass(), null, tracer.getCopy());
+            }
+            for (RelationshipDefinition definition : getRelationships()) {
+                definition.completeValidation(getEntryClass(), null, tracer.getCopy());
+            }
+        } else {
+            tracer.addBean(this.getClass().getSimpleName(), toString() );
+            tracer.createError("DataObjectClass is not set,  remaining validations aborted", null );
         }
     }
 
@@ -400,33 +633,6 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
         return relationshipMap.keySet();
     }
 
-    /**
-     * @see org.springframework.beans.factory.InitializingBean#afterPropertiesSet()
-     */
-    public void afterPropertiesSet() throws Exception {
-        if (relationships != null) {
-            relationshipMap.clear();
-            for (RelationshipDefinition relationship : relationships) {
-                if (relationship == null) {
-                    throw new IllegalArgumentException("invalid (null) relationshipDefinition");
-                }
-                String relationshipName = relationship.getObjectAttributeName();
-                if (StringUtils.isBlank(relationshipName)) {
-                    throw new ValidationException("invalid (blank) relationshipName");
-                }
-                relationship.setSourceClass(getEntryClass());
-                relationshipMap.put(relationshipName, relationship);
-            }
-        }
-
-        //Populate attributes with nested attribute definitions
-        if (complexAttributes != null) {
-            for (ComplexAttributeDefinition complexAttribute : complexAttributes) {
-                addNestedAttributes(complexAttribute, complexAttribute.getName());
-            }
-        }
-    }
-
     /**
      * recursively add complex attributes
      *
@@ -473,7 +679,7 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
             attrDefCopy.setRequired(attrDefToCopy.isRequired());
 
         } catch (Exception e) {
-            e.printStackTrace();
+            LOG.warn( "Problem copying properties from attribute definition: " + attrDefToCopy, e);
         }
 
         return attrDefCopy;
@@ -482,6 +688,7 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
     /**
      * @see org.kuali.rice.krad.datadictionary.DataDictionaryEntry#getStateMapping()
      */
+    @Override
     @BeanTagAttribute(name = "stateMapping", type = BeanTagAttribute.AttributeType.SINGLEBEAN)
     public StateMapping getStateMapping() {
         return stateMapping;
@@ -490,7 +697,33 @@ abstract public class DataDictionaryEntryBase extends DictionaryBeanBase impleme
     /**
      * @see DataDictionaryEntry#setStateMapping(org.kuali.rice.krad.datadictionary.state.StateMapping)
      */
+    @Override
     public void setStateMapping(StateMapping stateMapping) {
         this.stateMapping = stateMapping;
     }
+
+    public boolean hasEmbeddedDataObjectMetadata() {
+        return getDataObjectMetadata() != null;
+    }
+
+    public DataObjectMetadata getDataObjectMetadata() {
+        return dataObjectMetadata;
+    }
+
+    public void setDataObjectMetadata(DataObjectMetadata dataObjectMetadata) {
+        this.dataObjectMetadata = dataObjectMetadata;
+    }
+
+    public Map<String, RelationshipDefinition> getRelationshipMap() {
+        if(relationshipMap.isEmpty() && !getRelationships().isEmpty()){
+            for(RelationshipDefinition rel : getRelationships()){
+                relationshipMap.put(rel.getObjectAttributeName(),rel);
+            }
+        }
+        return relationshipMap;
+    }
+
+    public void setRelationshipMap(Map<String, RelationshipDefinition> relationshipMap) {
+        this.relationshipMap = relationshipMap;
+    }
 }
