@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2016 The Kuali Foundation
+ * Copyright 2005-2018 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
  */
 package org.kuali.rice.krad.web.form;
 
+import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.commons.lang.StringUtils;
-import org.codehaus.jackson.map.ObjectMapper;
 import org.kuali.rice.krad.service.KRADServiceLocatorWeb;
 import org.kuali.rice.krad.uif.UifConstants;
 import org.kuali.rice.krad.uif.UifConstants.ViewType;
@@ -29,22 +29,13 @@ import org.kuali.rice.krad.uif.service.ViewService;
 import org.kuali.rice.krad.uif.util.SessionTransient;
 import org.kuali.rice.krad.uif.view.View;
 import org.kuali.rice.krad.uif.view.ViewModel;
-import org.kuali.rice.krad.util.CsrfValidator;
 import org.kuali.rice.krad.util.KRADUtils;
 import org.kuali.rice.krad.web.bind.RequestAccessible;
 import org.springframework.web.multipart.MultipartFile;
 
 import javax.servlet.http.HttpServletRequest;
 import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Enumeration;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Set;
-import java.util.UUID;
+import java.util.*;
 
 /**
  * Base form class for views within the KRAD User Interface Framework.
@@ -209,12 +200,13 @@ public class UifFormBase implements ViewModel {
     protected Map<String, Boolean> actionFlags;
     protected Map<String, Boolean> editModes;
 
-    protected String csrfToken;
-
+    @SessionTransient
     protected HttpServletRequest request;
 
     private Object dialogDataObject;
 
+    private String csrfToken;
+
     public UifFormBase() {
         renderedInDialog = false;
         renderedInIframe = false;
@@ -257,7 +249,7 @@ public class UifFormBase implements ViewModel {
             setRequestedFormKey(formKeyParam);
         }
 
-        String csrfToken = CsrfValidator.getSessionToken(request);
+        String csrfToken = KRADServiceLocatorWeb.getCsrfService().getSessionToken(request);
         setCsrfToken(csrfToken);
 
         this.request = request;
