@@ -1,5 +1,5 @@
 --
--- Copyright 2005-2016 The Kuali Foundation
+-- Copyright 2005-2018 The Kuali Foundation
 --
 -- Licensed under the Educational Community License, Version 2.0 (the "License");
 -- you may not use this file except in compliance with the License.
@@ -15,6 +15,6 @@
 --
 
 -- Traveler Account Type change to use KualiCodeBase
--- KULRICE-11129 Samples for I22
-ALTER TABLE TRV_ACCT_TYPE ADD ACTV_IND VARCHAR(1)
+-- KULRICE-11129 Samples for I22, population of fields with initial values
+UPDATE TRV_ACCT_TYPE SET ACTV_IND="Y"
 /
\ No newline at end of file
